@@ -28,7 +28,7 @@ class Confhd(ConfhdTemplate):
 
         self.dir_base = os.path.split(file_name)[0]
         self.nome_arquivo = os.path.split(file_name)[1]
-
+        self._copiavazoes = vazoes.vaz_nat
         self._numero_registros_ = 0
         self.nuhe = 0
 
@@ -196,6 +196,9 @@ class Confhd(ConfhdTemplate):
 
         formato = "{codigo: >5} {nome: <12} {posto: >4} {jusante: >5} {ree: >4} {vol_ini: >6} {status: >4} {modif: >6} {ano_i: >8} {ano_f: >8}\n"
 
+        if not os.path.isdir(os.path.split(file_out)[0]):
+            os.mkdir(os.path.split(file_out)[0])
+
         try:
 
             with open(file_out, 'w', encoding='latin-1') as f:  # type: IO[str]
@@ -430,6 +433,12 @@ class Confhd(ConfhdTemplate):
         self._ro_min['valor'][posicao] = uhe['ro_min']
         self._ro_max['valor'][posicao] = uhe['ro_max']
         self._engolimento['valor'][posicao] = uhe['engolimento']
+
+        print(np.shape(self._copiavazoes))
+        for iano in range(np.shape(self._copiavazoes)[0]):
+            for imes in range(12):
+                self._copiavazoes[iano][imes][self._posto['valor'][posicao]-1] = self._vazoes['valor'][posicao][iano][imes]
+
         return 'sucesso'
 
     def help(self, parametro):
